# More easy python

This package is for making python even easier (it also adds some function)


## Installation

Install moreezpython with pip

```bash
  pip install moreezpython
```
    
## Usage/Examples

```python
import file.moreezpython as mep

mep.help()
```


## Features

- Log with colors for easy reading
- Allows to count for example print the number of seconds to wait
- Easy Features



## License

This project was done independently, to respect my work it is forbidden to copy the code of the package moreover it is forbidden to modify the source code to sell the package



## Badges


[![MIT License](https://img.shields.io/badge/License-MIT-green.svg)](https://choosealicense.com/licenses/mit/)

![GitHub repo size](https://img.shields.io/github/repo-size/Maelus-999/ezpython)

![PyPI](https://img.shields.io/pypi/v/moreezpython)

![pyver](https://img.shields.io/badge/min%20python%20version-v2.7-green)

